/*  Master file

FILES CALLED:  

mergedata.do sets up the trains dataset with the factor data and various goods type classifications
indices.do  calculates all the indices
factorindices.do   creates relative factor endowments for exporter j relative to rest of world
reglist.do  and reglist2.do   are standard regressions

The file works through various subsamples of the data as follows...


1.  all data
2. top 50% countries by Y/L
3. bottom 50% countries by Y/L
4. capital + intermediates only
5.  consumption goods only
6.  Rauch diff'd goods
7.  sitc 5-8 goods
6.  all data, at digits 1...6

*/ 


capture program drop decomp	
program define decomp

clear
capture log close

global YR 1995

set mem 800m


do mergedata       /* creates tempy which is a dataset used several times */


/* base regression:    this output is used in Tables 2, 3, and creates inputs into Table 5;  

the temporary file created here, tempbase, is also used to create the appendixtable using appendixtable.do  */

use tempy
do indices
do factorindices
save tempbase, replace

log using trainsdecomp.log, text replace
do reglist
log close

/*    In order to do regressions that break out factors K, H, A separately instead of just Y, Y/L, do the following... */

use temp_hka
do indices
do factorindices_hka
save tempbase_hka, replace

log using trainsdecomp_hka.log, text replace
do reglist2
log close


/* split the sample top and bottom */

clear
use tempbase if bottom == 0 
log using trainsdecomptop.log, text replace

/* these are top 50% countries */

do reglist
log close

clear
use tempbase if bottom == 1
log using trainsdecompbottom.log, text replace

/* these are bottom 50% countries */

do reglist
log close


clear

/*  Redo the top / bottom split breaking out factors K, H, A separately */

use tempbase_hka if bottom == 0 
log using trainsdecomptop_hka.log, text replace

/* these are top 50% countries */

do reglist2
log close


clear
use tempbase_hka if bottom == 1
log using trainsdecompbottom_hka.log, text replace

/* these are bottom 50% countries */
do reglist2
log close



/* re-do datasets for K, C goods  */

clear
use tempy if kaptype==0
do indices
do factorindices
log using trainsdecompkap, text replace
do reglist
log close


clear
use tempy if kaptype==1
do indices
do factorindices
log using trainsdecompconsum, text replace
do reglist
log close


clear
use temp_hka if kaptype==0
do indices
do factorindices_hka
log using trainsdecompkap_hka, text replace
do reglist2
log close


clear
use temp_hka if kaptype==1
do indices
do factorindices_hka
log using trainsdecompconsum_hka, text replace
do reglist2
log close


/*  do rauch and sitc type breakdowns 


/* call indices.do to do calculations on each type */

clear
use tempy if rauchtype==1
do indices
do factorindices
log using trainsdecomprauch,text  replace
do reglist
log close

clear
use tempy if sitctype==1
do indices
do factorindices
log using trainsdecompsitc,text  replace
do reglist
log close


clear
use temp_hka if rauchtype==1
do indices
do factorindices_hka
log using trainsdecomprauch_hka,text  replace
do reglist2
log close

clear
use temp_hka if sitctype==1
do indices
do factorindices_hka
log using trainsdecompsitc_hka,text  replace
do reglist2
log close


/* LOOP THROUGH 1...6 DIGITS Files */

global DIG 6

while $DIG > 0 {

do createdigitsdata
log using trainsdecompdigitsnew.log, append

di "DIGITS = " $DIG

reg lnOVER_j lnyl_jwj lnl_jwj
reg lnINT_j lnyl_jwj lnl_jwj
reg lnEXT_j lnyl_jwj lnl_jwj


reg lnOVER_j lny_jwj 
reg lnINT_j lny_jwj
reg lnEXT_j lny_jwj


log close
global DIG = $DIG - 1
}




end











